==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/ProviderRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.ProviderRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property softDeleteTTL
 * @property subscriptionStateOverrideActions
 */
public data class ProviderRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs(
    public val softDeleteTTL: Output<String>? = null,
    public val subscriptionStateOverrideActions: Output<List<SubscriptionStateOverrideActionArgs>>? =
        null,
) :
    ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.ProviderRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs> {
    override fun toJava():
        com.pulumi.azurenative.providerhub.inputs.ProviderRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs =
        com.pulumi.azurenative.providerhub.inputs.ProviderRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs.builder()
            .softDeleteTTL(softDeleteTTL?.applyValue({ args0 -> args0 }))
            .subscriptionStateOverrideActions(
                subscriptionStateOverrideActions?.applyValue({ args0 ->
                    args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            ).build()
}

/**
 * Builder for [ProviderRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs].
 */
@PulumiTagMarker
public class
ProviderRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgsBuilder
internal constructor() {
    private var softDeleteTTL: Output<String>? = null

    private var subscriptionStateOverrideActions: Output<List<SubscriptionStateOverrideActionArgs>>? =
        null

    /**
     * @param value
     */
    @JvmName("tuhelsdloglstqdi")
    public suspend fun softDeleteTTL(`value`: Output<String>) {
        this.softDeleteTTL = value
    }

    /**
     * @param value
     */
    @JvmName("kypnheaykyeaxfmx")
    public suspend
    fun subscriptionStateOverrideActions(`value`: Output<List<SubscriptionStateOverrideActionArgs>>) {
        this.subscriptionStateOverrideActions = value
    }

    @JvmName("eiunpgvoxfbificf")
    public suspend fun subscriptionStateOverrideActions(
        vararg
        values: Output<SubscriptionStateOverrideActionArgs>,
    ) {
        this.subscriptionStateOverrideActions = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("jayundfkkpyodobk")
    public suspend
    fun subscriptionStateOverrideActions(values: List<Output<SubscriptionStateOverrideActionArgs>>) {
        this.subscriptionStateOverrideActions = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("krgpcjveuxdmsjlq")
    public suspend fun softDeleteTTL(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.softDeleteTTL = mapped
    }

    /**
     * @param value
     */
    @JvmName("jffwynkgraswasqu")
    public suspend
    fun subscriptionStateOverrideActions(`value`: List<SubscriptionStateOverrideActionArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.subscriptionStateOverrideActions = mapped
    }

    /**
     * @param argument
     */
    @JvmName("pmcevvdaruiarwcm")
    public suspend
    fun subscriptionStateOverrideActions(argument: List<suspend SubscriptionStateOverrideActionArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            SubscriptionStateOverrideActionArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.subscriptionStateOverrideActions = mapped
    }

    /**
     * @param argument
     */
    @JvmName("kqfwkxbihsixfaoa")
    public suspend fun subscriptionStateOverrideActions(
        vararg
        argument: suspend SubscriptionStateOverrideActionArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            SubscriptionStateOverrideActionArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.subscriptionStateOverrideActions = mapped
    }

    /**
     * @param argument
     */
    @JvmName("aanduisngwtshskm")
    public suspend
    fun subscriptionStateOverrideActions(argument: suspend SubscriptionStateOverrideActionArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            SubscriptionStateOverrideActionArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.subscriptionStateOverrideActions = mapped
    }

    /**
     * @param values
     */
    @JvmName("nilpkdacdrebkbnf")
    public suspend fun subscriptionStateOverrideActions(
        vararg
        values: SubscriptionStateOverrideActionArgs,
    ) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.subscriptionStateOverrideActions = mapped
    }

    internal fun build():
        ProviderRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs =
        ProviderRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs(
            softDeleteTTL = softDeleteTTL,
            subscriptionStateOverrideActions = subscriptionStateOverrideActions,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/ProviderRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.ProviderRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property softDeleteTTL
 * @property subscriptionStateOverrideActions
 */
public data class ProviderRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs(
    public val softDeleteTTL: Output<String>? = null,
    public val subscriptionStateOverrideActions: Output<List<SubscriptionStateOverrideActionArgs>>? =
        null,
) :
    ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.ProviderRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs> {
    override fun toJava():
        com.pulumi.azurenative.providerhub.inputs.ProviderRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs =
        com.pulumi.azurenative.providerhub.inputs.ProviderRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs.builder()
            .softDeleteTTL(softDeleteTTL?.applyValue({ args0 -> args0 }))
            .subscriptionStateOverrideActions(
                subscriptionStateOverrideActions?.applyValue({ args0 ->
                    args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            ).build()
}

/**
 * Builder for [ProviderRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs].
 */
@PulumiTagMarker
public class
ProviderRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgsBuilder
internal constructor() {
    private var softDeleteTTL: Output<String>? = null

    private var subscriptionStateOverrideActions: Output<List<SubscriptionStateOverrideActionArgs>>? =
        null

    /**
     * @param value
     */
    @JvmName("tskbcexbnviqsgxb")
    public suspend fun softDeleteTTL(`value`: Output<String>) {
        this.softDeleteTTL = value
    }

    /**
     * @param value
     */
    @JvmName("bmcsrcremywmpqgk")
    public suspend
    fun subscriptionStateOverrideActions(`value`: Output<List<SubscriptionStateOverrideActionArgs>>) {
        this.subscriptionStateOverrideActions = value
    }

    @JvmName("xnvqiafcegqwfhpu")
    public suspend fun subscriptionStateOverrideActions(
        vararg
        values: Output<SubscriptionStateOverrideActionArgs>,
    ) {
        this.subscriptionStateOverrideActions = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("fritlhlwgqiepuqd")
    public suspend
    fun subscriptionStateOverrideActions(values: List<Output<SubscriptionStateOverrideActionArgs>>) {
        this.subscriptionStateOverrideActions = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("igkxtblvhckjxuid")
    public suspend fun softDeleteTTL(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.softDeleteTTL = mapped
    }

    /**
     * @param value
     */
    @JvmName("mncebmahrdxncoiy")
    public suspend
    fun subscriptionStateOverrideActions(`value`: List<SubscriptionStateOverrideActionArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.subscriptionStateOverrideActions = mapped
    }

    /**
     * @param argument
     */
    @JvmName("kkrcanbbgmkbgcmh")
    public suspend
    fun subscriptionStateOverrideActions(argument: List<suspend SubscriptionStateOverrideActionArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            SubscriptionStateOverrideActionArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.subscriptionStateOverrideActions = mapped
    }

    /**
     * @param argument
     */
    @JvmName("tljgakvwxiawekuf")
    public suspend fun subscriptionStateOverrideActions(
        vararg
        argument: suspend SubscriptionStateOverrideActionArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            SubscriptionStateOverrideActionArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.subscriptionStateOverrideActions = mapped
    }

    /**
     * @param argument
     */
    @JvmName("wybsiytrwhibvnng")
    public suspend
    fun subscriptionStateOverrideActions(argument: suspend SubscriptionStateOverrideActionArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            SubscriptionStateOverrideActionArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.subscriptionStateOverrideActions = mapped
    }

    /**
     * @param values
     */
    @JvmName("lhyjpemppdsvtyjp")
    public suspend fun subscriptionStateOverrideActions(
        vararg
        values: SubscriptionStateOverrideActionArgs,
    ) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.subscriptionStateOverrideActions = mapped
    }

    internal fun build():
        ProviderRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs =
        ProviderRegistrationPropertiesSubscriptionLifecycleNotificationSpecificationsArgs(
            softDeleteTTL = softDeleteTTL,
            subscriptionStateOverrideActions = subscriptionStateOverrideActions,
        )
}
